Code generation utilities for Spikard
This crate provides utilities for generating test infrastructure and type definitions
from fixture files and OpenAPI schemas.
Re-exports
pub use error::CodegenError;pub use error::Result;
Code generation utilities for Spikard
This crate provides utilities for generating test infrastructure and type definitions
from fixture files and OpenAPI schemas.
pub use error::CodegenError;pub use error::Result;