load_fixtures_from_dir

Function load_fixtures_from_dir 

pub fn load_fixtures_from_dir(dir: &Path) -> Result<Vec<Fixture>>
Load fixtures from a directory

Errors

Returns an error if the directory cannot be read or if a fixture file is invalid.

Panics

Panics if a filename in the directory cannot be converted to a string.