pub fn default_status_for(
command: &QueryCommand,
method: HttpMethod,
) -> Result<u16, AnnotationParseError>Expand description
Validate that the HTTP method declared on a query is compatible with the
scythe QueryCommand, and return the default status code for the (command,
method) pair when HttpAnnotations::status_codes is empty.